@@ -879,8 +879,13 @@ for base_path in path_args:
             if '.tox' in dirs:
                 dirs.remove('.tox')
             for f in files:
+                file_path = os.path.join(subdir, f)
+                if 'environments/services-docker' in file_path:
+                    print("WARNING: environments/services-docker should not be used "
+                          "any more, use environments/services instead: %s " %
+                          file_path)
+
                 if f.endswith('.yaml') and not f.endswith('.j2.yaml'):
-                    file_path = os.path.join(subdir, f)
                     failed = validate(file_path, param_map)
                     if failed:
                         failed_files.append(file_path)
